

models.Property
===============

.. autoclass:: pykechain.models.Property2
   :members:

pykechain Property Types
------------------------

.. autoclass:: pykechain.models.AttachmentProperty2
   :members:

.. autoclass:: pykechain.models.MultiReferenceProperty2
   :members:

.. autoclass:: pykechain.models.SelectListProperty2
   :members:

.. autoclass:: pykechain.models.DatetimeProperty2
   :members:
